@@ -118,7 +118,6 @@ class Middleware:
         If such is not found, the handlers are not installed.
         """
         try:
-            print "NANANANA"
             config = settings.AUTHENTICATION_THROTTLING
             self.delay_function = config["DELAY_FUNCTION"]
             self.logins = list(config["LOGIN_URLS_WITH_TEMPLATES"])
@@ -128,7 +127,6 @@ class Middleware:
             self.process_request = self._process_request_if_configured
             self.process_response = self._process_response_if_configured
         except:
-            print "HELLO"
             logger.error("Bad AUTHENTICATION_THROTTLING dictionary. "
                            "AuthenticationThrottlingMiddleware disabled.")
 
@@ -149,7 +147,6 @@ class Middleware:
         Block the request if it is a login attempt to which a throttling delay
         is applicable.
         """
-        print "WEEEE"
         if request.method != "POST": return
         for url, template_name in self.logins:
             if request.path[1:] != url: continue
